@@ -11,7 +11,7 @@ use List::Util qw(shuffle);
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-10-21'; # DATE
 our $DIST = 'App-wordlist'; # DIST
-our $VERSION = '0.279'; # VERSION
+our $VERSION = '0.280'; # VERSION
 
 our %SPEC;
 
@@ -73,26 +73,22 @@ sub _list_installed {
 sub _word_has_chars_unordered {
     my ($word, $chars, $ci) = @_;
 
-    return 1 unless length $word;
-
     if ($ci) {
         $word = lc $word;
         $chars = lc $chars;
     }
 
     for my $i (0..length($chars)-1) {
-        return 1 unless length $word;
         my $char = substr($chars, $i, 1);
-        $word =~ s/\Q$char\E// or return 0;
+        $word =~ s/\Q$char\E//;
     }
-    1;
+
+    return length $word ? 0:1;
 }
 
 sub _word_has_chars_ordered {
     my ($word, $chars, $ci) = @_;
 
-    return 1 unless length $word;
-
     if ($ci) {
         $word = lc $word;
         $chars = lc $chars;
@@ -100,7 +96,6 @@ sub _word_has_chars_ordered {
 
     my $last_index;
     for my $i (0..length($chars)-1) {
-        return 1 unless length $word;
         my $char = substr($chars, $i, 1);
         my $index = index($word, $char);
         return 0 if $index < 0;
@@ -567,7 +562,7 @@ App::wordlist - Grep words from WordList::*
 
 =head1 VERSION
 
-This document describes version 0.279 of App::wordlist (from Perl distribution App-wordlist), released on 2021-10-21.
+This document describes version 0.280 of App::wordlist (from Perl distribution App-wordlist), released on 2021-10-21.
 
 =head1 SYNOPSIS
 
